package Sandbox::Tags;
use strict;

sub body_class {
    my $ctx = shift;
    my $args    = shift;
    
    my $entry = $ctx->stash('entry');
    my $is_page = $entry && $entry->isa('MT::Page');
    my $blog = $ctx->stash('blog');
    my $vars = $ctx->stash('vars');
    
    use Data::Dumper;
    # return Dumper $ctx->stash('entry');
    # return Dumper $ctx->stash('blog');
    # return Dumper $ctx->stash('vars');
    
    
    
    my $classes = ""; #the "wordpress" class goes on everything, but we're making it optional
    
    # TODO pagination, once it is implemented in MT
    # right now, pagination does not exist in MT
    
    if($vars)
    {
        if($vars->{'archive_class'} && !$is_page)
        {
            # we are in an archive
            $classes .= " archive";
            my $archiveclass = $vars->{'archive_class'};
            if($archiveclass eq 'entry-archive')
            {
                $classes .= " single";
                if($entry)
                {
                    my $author = $entry->author;
                    $classes .= " s-author-".$author->name;
                    my $catsref = $entry->categories;
                    my @cats = @$catsref;
                    my $catsize = @cats;
                    my $i = 0;
                    for($i = 0; $i < $catsize; $i++)
                    {
                        $classes .= " s-category-".$cats[$i]->basename;
                    }
                    my @tags = $entry->tags;
                    my $tagsize = @tags;
                    for($i = 0; $i < $tagsize; $i++)
                    {
                        $classes .= " tag-" . MT::Util::dirify($tags[$i]);
                    }
                    $classes .= " postid-" . $entry->id;
                    $classes .= " s-d" . MT::Util::format_ts("%d",$entry->created_on); # day
                    $classes .= " s-m" . MT::Util::format_ts("%m",$entry->created_on); # month
                    $classes .= " s-y" . MT::Util::format_ts("%Y",$entry->created_on); # year
                    $classes .= " s-h" . MT::Util::format_ts("%H",$entry->created_on); # hour
                }
            }
            if($archiveclass eq 'category-archive' || $archiveclass eq 'category-monthly-archive')
            {
                $classes .= " category";
                $classes .= " category-".$ctx->_hdlr_archive_title($args,{});
                #category page num
            }
            if($archiveclass eq 'author-archive' || $archiveclass eq 'author-monthly-archive')
            {
                $classes .= " author";
                if($entry)
                {
                    my $author = $entry->author;
                    $classes .= " author-".$author->name;
                }
                #author page num
            }
            if($archiveclass eq 'category-monthly-archive' ||
               $archiveclass eq 'datebased-monthly-archive'||
               $archiveclass eq 'author-monthly-archive' ||
               $archiveclass eq 'tag-monthly-archive')
            {
                $classes .= " date";
                #date page num
            }
        }
        elsif (!$is_page)
        {
            if($vars->{'search_results'})
            {
                $classes .= " search";
            }
            elsif($vars->{'comment_preview'})
            {
                $classes .= " comment-preview";
            }
            elsif($vars->{'comment_response'})
            {
                $classes .= " comment-response";
            }
            else
            {
                $classes .= " home";
            }
        }
    }
    if ($is_page)
    {
        if($entry)
        {
            my $author = $entry->author;
            $classes .= " page-author-".$author->name;
        }
        $classes .= " page";
    }

    return $classes;
}

sub entry_class {
    my $ctx = shift;
    my $args    = shift;
    
    my $entry = $ctx->stash('entry');
    my $vars = $ctx->stash('vars');
    
    #use Data::Dumper;
    #return Dumper $ctx->stash('entry');
    #return Dumper $ctx->stash('blog');
    
    my $classes = "hentry post publish";

    if($entry)
    {
        $classes .= " d" . MT::Util::format_ts("%d",$entry->created_on); # day
        $classes .= " m" . MT::Util::format_ts("%m",$entry->created_on); # month
        $classes .= " y" . MT::Util::format_ts("%Y",$entry->created_on); # year
        $classes .= " h" . MT::Util::format_ts("%H",$entry->created_on); # 24 hour
        my $author = $entry->author;
        $classes .= " author-".$author->name;
        my $catsref = $entry->categories;
        my @cats = @$catsref;
        my $catsize = @cats;
        my $i = 0;
        for($i = 0; $i < $catsize; $i++)
        {
            $classes .= " category-".$cats[$i]->label;
        }
        my @tags = $entry->tags;
        my $tagsize = @tags;
        for($i = 0; $i < $tagsize; $i++)
        {
            $classes .= " tag-".$tags[$i];
        }
        my $counter = $vars->{'__counter__'};
        if($counter)
        {
            $classes .= " p" . $counter;
        }
        if($vars->{'__even__'})
        {
            $classes .= " alt";
        }
        if ($entry->isa('MT::Page'))
        {
            $classes .= " page";
        }
    }

    return $classes;
}

sub comment_class {
    my $ctx = shift;
    my $args    = shift;

    my $vars = $ctx->stash('vars');
    my $entry = $ctx->stash('entry');
    my $comment = $ctx->stash('comment');
    
    #use Data::Dumper;
    #return Dumper $ctx->stash('entry');
    #return Dumper $ctx->stash('blog');
    #return Dumper $ctx->stash('comment');
    
    my $classes = "comment"; 

    if($comment)
    {
        $classes .= " c-d" . MT::Util::format_ts("%d",$comment->created_on); # day
        $classes .= " c-m" . MT::Util::format_ts("%m",$comment->created_on); # month
        $classes .= " c-y" . MT::Util::format_ts("%Y",$comment->created_on); # year
        $classes .= " c-h" . MT::Util::format_ts("%H",$comment->created_on); # 24 hour
        my $entryauthorid = $entry->author->id;
        my $commentauthor = $comment->author;
        my $commentauthorid = $comment->commenter_id;
        if($commentauthorid)
        {
            $classes .= " comment-author-".$commentauthor;
            if($entryauthorid == $commentauthorid)
            {
                $classes .= " bypostauthor";
            }
            else
            {
                $classes .= " byuser";
            }
        }
        my $counter = $vars->{'__counter__'};
        $classes .= " c" . $counter;
        if($vars->{'__even__'})
        {
            $classes .= " alt";
        }
    }
    
    
    return $classes;
}

sub trackback_class {
    my $ctx = shift;
    my $args    = shift;

    my $vars = $ctx->stash('vars');
    my $trackback = $ctx->stash('ping');
    
    #use Data::Dumper;
    #return Dumper $ctx->stash('entry');
    #return Dumper $ctx->stash('blog');
    #return Dumper $ctx->stash('comment');
    
    my $classes = "trackback"; 

    if($trackback)
    {
        $classes .= " c-d" . MT::Util::format_ts("%d",$trackback->created_on); # day
        $classes .= " c-m" . MT::Util::format_ts("%m",$trackback->created_on); # month
        $classes .= " c-y" . MT::Util::format_ts("%Y",$trackback->created_on); # year
        $classes .= " c-h" . MT::Util::format_ts("%H",$trackback->created_on); # 24 hour
        
        my $counter = $vars->{'__counter__'};
        $classes .= " t" . $counter;
        if($vars->{'__even__'})
        {
            $classes .= " alt";
        }
    }
    
    
    return $classes;
}

sub if_feedback_enabled {
    my $ctx = shift;
    my $entry = $ctx->stash('entry');
    
    if($entry)
    {
        if($entry->comment_count > 0 || $entry->ping_count > 0 || $entry->allow_comments || $entry->allow_pings)
        {
            return 1;
        }
    }
    
    return 0;
}

1;